
<p class="center">
  <a href="https://codecov.io/gh/jockerz/Starlette-Login" target="_blank">
    <img src="https://img.shields.io/codecov/c/github/jockerz/Starlette-Login?color=%2334D058" alt="Coverage">
  </a>
  <a href="https://github.com/jockerz/Starlette-Login/actions">
    <img src='https://github.com/jockerz/Starlette-Login/actions/workflows/python-package.yml/badge.svg' alt='Test Status' />
  </a>
  <a href="https://pypi.org/project/Starlette-Login">
    <img src='https://img.shields.io/pypi/v/Starlette-Login?color=%2334D058&label=pypi%20package' alt='Package Version' />
  </a>
  <a href="https://pypi.org/project/Starlette-Login">
    <img src='https://img.shields.io/pypi/pyversions/Starlette-Login.svg?color=%2334D058' alt='Supported Python versions' />
  </a>
  <a href='https://starlette-login.readthedocs.io/en/stable/?badge=stable'>
    <img src='https://readthedocs.org/projects/starlette-login/badge/?version=stable' alt='Documentation Status' />
  </a>
</p>


## Introduction

[https://starlette-login.readthedocs.io](https://starlette-login.readthedocs.io/en/stable/)

Starlette-Login provides user session management for Starlette.
Much inspired by [Flask-Login][Flask-Login], 
it handles the common tasks of logging in, logging out, 
and remembering your users' sessions over extended periods of time.


## Installation

```shell
pip install Starlette-Login
```


## Usage Examples
 
 - [Starlette-Login-Example](https://github.com/jockerz/Starlette-Login-Example): Basic example the usage of Starlette-Login using `basic auth` Authentication


[Documentation]: https://github.com/jockerz/Starlette-Login
[Flask-Login]: https://flask-login.readthedocs.io
